==> igniteui-react-core-16.16.1.tgz: package/esm2015/lib/GeographicMarkerSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { GeographicMapSeriesHostDescription } from "./GeographicMapSeriesHostDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let GeographicMarkerSeriesDescription = /*@__PURE__*/ (() => {
    class GeographicMarkerSeriesDescription extends GeographicMapSeriesHostDescription {
        constructor() {
            super();
            this.di = null;
            this.c6 = 0;
            this.dg = null;
            this.de = null;
            this.dh = null;
            this.dd = null;
            this.df = null;
            this.c8 = 0;
            this.dc = null;
            this.da = null;
            this.db = null;
        }
        get_type() {
            return "GeographicMarkerSeries";
        }
        get markerType() {
            return this.di;
        }
        set markerType(a) {
            this.di = a;
            this.e("MarkerType");
        }
        get markerThickness() {
            return this.c6;
        }
        set markerThickness(a) {
            this.c6 = a;
            this.e("MarkerThickness");
        }
        get markerOutlineMode() {
            return this.dg;
        }
        set markerOutlineMode(a) {
            this.dg = a;
            this.e("MarkerOutlineMode");
        }
        get markerFillMode() {
            return this.de;
        }
        set markerFillMode(a) {
            this.de = a;
            this.e("MarkerFillMode");
        }
        get markerTemplateRef() {
            return this.dh;
        }
        set markerTemplateRef(a) {
            this.dh = a;
            this.e("MarkerTemplateRef");
        }
        get markerBrush() {
            return this.dd;
        }
        set markerBrush(a) {
            this.dd = a;
            this.e("MarkerBrush");
        }
        get markerOutline() {
            return this.df;
        }
        set markerOutline(a) {
            this.df = a;
            this.e("MarkerOutline");
        }
        get maximumMarkers() {
            return this.c8;
        }
        set maximumMarkers(a) {
            this.c8 = a;
            this.e("MaximumMarkers");
        }
        get actualMarkerTemplateRef() {
            return this.dc;
        }
        set actualMarkerTemplateRef(a) {
            this.dc = a;
            this.e("ActualMarkerTemplateRef");
        }
        get actualMarkerBrush() {
            return this.da;
        }
        set actualMarkerBrush(a) {
            this.da = a;
            this.e("ActualMarkerBrush");
        }
        get actualMarkerOutline() {
            return this.db;
        }
        set actualMarkerOutline(a) {
            this.db = a;
            this.e("ActualMarkerOutline");
        }
    }
    GeographicMarkerSeriesDescription.$t = /*@__PURE__*/ markType(GeographicMarkerSeriesDescription, 'GeographicMarkerSeriesDescription', GeographicMapSeriesHostDescription.$);
    return GeographicMarkerSeriesDescription;
})();

==> igniteui-react-core-19.0.0.tgz: package/esm2015/lib/GeographicMarkerSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { GeographicMapSeriesHostDescription } from "./GeographicMapSeriesHostDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let GeographicMarkerSeriesDescription = /*@__PURE__*/ (() => {
    class GeographicMarkerSeriesDescription extends GeographicMapSeriesHostDescription {
        get_type() {
            return "GeographicMarkerSeries";
        }
        constructor() {
            super();
            this.fl = null;
            this.e9 = 0;
            this.fj = null;
            this.fh = null;
            this.fk = null;
            this.fg = null;
            this.fi = null;
            this.fb = 0;
            this.ff = null;
            this.fd = null;
            this.fe = null;
        }
        get markerType() {
            return this.fl;
        }
        set markerType(a) {
            this.fl = a;
            this.g("MarkerType");
        }
        get markerThickness() {
            return this.e9;
        }
        set markerThickness(a) {
            this.e9 = a;
            this.g("MarkerThickness");
        }
        get markerOutlineMode() {
            return this.fj;
        }
        set markerOutlineMode(a) {
            this.fj = a;
            this.g("MarkerOutlineMode");
        }
        get markerFillMode() {
            return this.fh;
        }
        set markerFillMode(a) {
            this.fh = a;
            this.g("MarkerFillMode");
        }
        get markerTemplateRef() {
            return this.fk;
        }
        set markerTemplateRef(a) {
            this.fk = a;
            this.g("MarkerTemplateRef");
        }
        get markerBrush() {
            return this.fg;
        }
        set markerBrush(a) {
            this.fg = a;
            this.g("MarkerBrush");
        }
        get markerOutline() {
            return this.fi;
        }
        set markerOutline(a) {
            this.fi = a;
            this.g("MarkerOutline");
        }
        get maximumMarkers() {
            return this.fb;
        }
        set maximumMarkers(a) {
            this.fb = a;
            this.g("MaximumMarkers");
        }
        get actualMarkerTemplateRef() {
            return this.ff;
        }
        set actualMarkerTemplateRef(a) {
            this.ff = a;
            this.g("ActualMarkerTemplateRef");
        }
        get actualMarkerBrush() {
            return this.fd;
        }
        set actualMarkerBrush(a) {
            this.fd = a;
            this.g("ActualMarkerBrush");
        }
        get actualMarkerOutline() {
            return this.fe;
        }
        set actualMarkerOutline(a) {
            this.fe = a;
            this.g("ActualMarkerOutline");
        }
    }
    GeographicMarkerSeriesDescription.$t = /*@__PURE__*/ markType(GeographicMarkerSeriesDescription, 'GeographicMarkerSeriesDescription', GeographicMapSeriesHostDescription.$);
    return GeographicMarkerSeriesDescription;
})();
